@@ -1,7 +1,10 @@
-/**
- * GJay, copyright (c) 2002 Chuck Groom. Sections of this code come
- * from spectromatic, copyright (C) 1997-2002 Daniel Franklin, and 
- * BpmDJ by Werner Van Belle.
+/*
+ * Gjay - Gtk+ DJ music playlist creator
+ * Copyright (C) 2010 Craig Small 
+ * Copyright (C) 2002 Chuck Groom.
+ *
+ * Sections of this code come from spectromatic, copyright (C)
+ * 1997-2002 Daniel Franklin, and BpmDJ by Werner Van Belle.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -14,9 +17,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Analysis.c -- manages the background threads and processes involved
  * in song analysis.
@@ -378,7 +379,13 @@ analyze(const char * fname,            /* File to analyze */
     send_analyze_song_name();
     send_ipc_text(daemon_pipe_fd, ANIMATE_START, analyze_song->path);
 
-    f = inflate_to_wav(fname, type);
+    if ( (f = inflate_to_wav(fname, type)) == NULL)
+    {
+      if (verbosity)
+        g_warning(_("Unable to inflate song '%s'.\n"), fname);
+      in_analysis = FALSE;
+      return;
+    }
     memset(&wsfile, 0x00, sizeof(wav_file));
     wsfile.f = f;
     fread(&wsfile.header, sizeof(waveheaderstruct), 1, f);
@@ -475,7 +482,7 @@ inflate_to_wav (const gchar * path, const song_file_type type)
           g_warning(_("Unable to decode '%s' as no mp3 decoder found"), path);
         return NULL;
       }
-      cmdline = g_strdup_printf("%s -b 10000 %s -w - 2> /dev/null",
+      cmdline = g_strdup_printf("%s -w - -b 10000 %s 2> /dev/null",
           mp3_decoder,
           quoted_path);
       break;
