@@ -1,6 +1,6 @@
 /**
  * GJay, copyright (c) 2002-2004 Chuck Groom
- *       Copyright (c) 2010 Craig Small
+ *       Copyright (c) 2010-2011 Craig Small
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -45,7 +45,6 @@
 #include <string.h>
 #include <ctype.h>
 #include "gjay.h"
-#include "gjay_audacious.h"
 #include "dbus.h"
 #include "analysis.h"
 #include "ipc.h"
@@ -53,8 +52,8 @@
 #include "vorbis.h"
 #include "flac.h"
 #include "ui.h"
-#include "gjay_audacious.h"
 #include "i18n.h"
+#include "play_common.h"
 
 GjayApp *gjay;
 
@@ -73,8 +72,9 @@ static gboolean create_ui_daemon_pipe(void);
 static gboolean mode_attached ( gjay_mode m );
 static void     fork_or_connect_to_daemon(void);
 static void     run_as_ui      (int argc, char * argv[]);
-static void     run_as_playlist  ( gboolean m3u_format, 
-                                   gboolean playlist_in_audacious );
+static void     run_as_playlist  ( guint playlist_minutes,
+    gboolean m3u_format, 
+    gboolean player_autostart );
 void gjay_message_log(const gchar *log_domain, 
     GLogLevelFlags log_level,
     const gchar *message,
@@ -87,7 +87,7 @@ print_version(const gchar *option_name, const gchar *value, gpointer data, GErro
   fprintf(stderr, _("GJay version %s\n"), VERSION);
   fprintf(stderr,
       "Copyright (C) 2002-2004 Chuck Groom\n"
-      "Copyright (C) 2010 Craig Small\n\n");
+      "Copyright (C) 2010-2011 Craig Small\n\n");
 	fprintf(stderr,
 		_("GJay comes with ABSOLUTELY NO WARRANTY.\n"
     "This program is free software; you can redistribute it and/or modify\n"
@@ -98,10 +98,9 @@ print_version(const gchar *option_name, const gchar *value, gpointer data, GErro
 }
 
 static void
-parse_commandline(int *argc_p, char ***argv_p, gboolean *m3u_format, gboolean *run_player, gchar **analyze_detached_fname)
+parse_commandline(int *argc_p, char ***argv_p, guint *playlist_minutes, gboolean *m3u_format, gboolean *run_player, gchar **analyze_detached_fname)
 {
   gboolean opt_daemon=FALSE, opt_playlist=FALSE;
-  gint opt_length=0;
   gchar *opt_standalone=NULL, *opt_color=NULL, *opt_file=NULL;
   GError *error;
   GOptionContext *context;
@@ -112,12 +111,12 @@ parse_commandline(int *argc_p, char ***argv_p, gboolean *m3u_format, gboolean *r
     { "color", 'c', 0, G_OPTION_ARG_STRING, &opt_color, _("Start playlist at color- Hex or name"), _("0xrrggbb|NAME") },
     { "daemon", 'd', 0, G_OPTION_ARG_NONE, &opt_daemon, _("Run as daemon"), NULL },
     { "file", 'f', 0, G_OPTION_ARG_STRING, &opt_file, _("Start playlist at file"), _("FILE") },
-    { "length", 'l', 0, G_OPTION_ARG_INT, &opt_length, _("Playlist length"), _("seconds") },
+    { "length", 'l', 0, G_OPTION_ARG_INT, &playlist_minutes, _("Playlist length"), _("minutes") },
     { "playlist", 'p', 0, G_OPTION_ARG_NONE, &opt_playlist, _("Generate a playlist"), NULL },
     { "skip-verification", 's', 0, G_OPTION_ARG_NONE, &skip_verify, _("Skip file verification"), NULL },
     { "m3u-playlist", 'u', 0, G_OPTION_ARG_NONE, m3u_format, _("Use M3U playlist format"), NULL },
     { "verbose", 'v', 0, G_OPTION_ARG_INT, &verbosity, "Set verbosity/debug level", _("LEVEL") },
-    { "play-audacious", 'P', 0, G_OPTION_ARG_NONE, run_player, _("Play generated playlist in Audacious"), NULL },
+    { "player-start", 'P', 0, G_OPTION_ARG_NONE, run_player, _("Start player using generated playlist"), NULL },
     { "version", 'V', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK , &print_version, _("Show version"), NULL },
     { NULL }
   };
@@ -179,7 +178,8 @@ parse_commandline(int *argc_p, char ***argv_p, gboolean *m3u_format, gboolean *r
 
 int main( int argc, char *argv[] ) {
   gchar * analyze_detached_fname=NULL;
-  gboolean m3u_format, playlist_in_audacious;
+  gboolean m3u_format, player_autostart;
+  guint playlist_minutes;
   gchar *gjay_home;
 
   srand(time(NULL));
@@ -192,11 +192,12 @@ int main( int argc, char *argv[] ) {
   mode = UI;
   verbosity = 0;    
   skip_verify = 0;
+  playlist_minutes = 0;
   m3u_format = FALSE;
-  playlist_in_audacious = FALSE;
+  player_autostart = FALSE;
   gjay->prefs = load_prefs();
    
-  parse_commandline(&argc, &argv, &m3u_format, &playlist_in_audacious, &analyze_detached_fname);
+  parse_commandline(&argc, &argv, &playlist_minutes, &m3u_format, &player_autostart, &analyze_detached_fname);
 
     /* Intialize vars */
     daemon_pipe_fd = -1;
@@ -255,7 +256,7 @@ int main( int argc, char *argv[] ) {
         break;
     case PLAYLIST:
         read_data_file();
-        run_as_playlist(m3u_format, playlist_in_audacious);
+        run_as_playlist(playlist_minutes, m3u_format, player_autostart);
         break;
     case DAEMON_INIT:
     case DAEMON_DETACHED: 
@@ -464,6 +465,7 @@ static void run_as_ui(int argc, char *argv[] )
   /* Ping the daemon ocassionally to let it know that the UI 
    * process is still around */
   gtk_timeout_add( UI_PING, ping_daemon, NULL);
+  player_init();
     make_app_ui();
     gtk_widget_show_all(gjay->main_window);
     gjay->connection = gjay_dbus_connection();
@@ -492,7 +494,7 @@ static void run_as_ui(int argc, char *argv[] )
     }        
     
     set_selected_file(NULL, NULL, FALSE);
-    audacious_is_running();
+    /*gjay->player_is_running();*/
     gtk_main();
     
     save_prefs();
@@ -513,7 +515,7 @@ static void run_as_ui(int argc, char *argv[] )
 
 
 /* Playlist mode */
-static void run_as_playlist(gboolean m3u_format, gboolean playlist_in_audacious)
+static void run_as_playlist(guint playlist_minutes, gboolean m3u_format, gboolean player_autostart)
 {
     GList * list;
     gjay->prefs->use_selected_songs = FALSE;
@@ -521,8 +523,10 @@ static void run_as_playlist(gboolean m3u_format, gboolean playlist_in_audacious)
     for (list = g_list_first(gjay->songs); list;  list = g_list_next(list)) {
         SONG(list)->in_tree = TRUE;
     }
-    list = generate_playlist(gjay->prefs->time);
-    if (playlist_in_audacious) {
+    if (playlist_minutes == 0)
+      playlist_minutes = gjay->prefs->time;
+    list = generate_playlist(playlist_minutes);
+    if (player_autostart) {
         play_songs(list);
     } else {
         write_playlist(list, stdout, m3u_format);
