@@ -1,9 +1,11 @@
-/**
- * GJay, copyright (c) 2002-4 Chuck Groom
+/*
+ * Gjay - Gtk+ DJ music playlist creator
+ * Copyright (C) 2002-2004 Chuck Groom
+ * Copyright (C) 2010-2011 Craig Small 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 1, or (at
+ * published by the Free Software Foundation; either version 2, or (at
  * your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
@@ -11,10 +13,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef GJAY_H
@@ -24,6 +24,7 @@
 
 /* Global definitions */
 #define AUDACIOUS_BIN "/usr/bin/audacious2"
+#define EXAILE_BIN "/usr/bin/exaile"
 
 #include <stdio.h>
 #include <gtk/gtk.h>
@@ -75,9 +76,13 @@ gchar * parent_dir            ( const char * path );
 
 struct _GjayApp {
   GjayPrefs *prefs;
-
+  /* Player connections/handles */
   DBusGConnection *connection;
-  DBusGProxy *audacious_proxy;
+  DBusGProxy *player_proxy;
+#ifdef WITH_MPDCLIENT
+  struct mpd_connection *mpdclient_connection;
+#endif /* WITH_MPDCLIENT */
+
 
   //GdkPixbuf   * pixbufs[PM_LAST];
   GdkPixbuf   * pixbufs[50]; //FIXME
@@ -110,6 +115,13 @@ struct _GjayApp {
   /* Supported filetypes */
   gboolean ogg_supported;
   gboolean flac_supported;
+
+
+  /* Player calls */
+  song* (*player_get_current_song)(void);
+  gboolean (*player_is_running)(void);
+  void (*player_play_files)(GList *list);
+  gboolean (*player_start)(void);
 };
 
 /* From daemon.c */
