@@ -1,9 +1,11 @@
 /**
- * GJay, copyright (c) 2002 Chuck Groom
+ * Gjay - Gtk+ DJ music playlist creator
+ * Copyright (C) 2002 Chuck Groom
+ * Copyright (C) 2010 Craig Small 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 1, or (at
+ * published by the Free Software Foundation; either version 2, or (at
  * your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
@@ -11,10 +13,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -27,6 +27,12 @@ typedef enum {
     PREF_DAEMON_ASK
 } pref_daemon_action;
 
+/* Music Player types */
+#define PLAYER_NONE 0
+#define PLAYER_AUDACIOUS 1
+#define PLAYER_MPDCLIENT 2
+#define PLAYER_LAST 3
+
 typedef struct {
     /* Root directory (latin1) */
     gchar   * song_root_dir;
@@ -68,6 +74,10 @@ typedef struct {
 
     /* Store how a color was loaded */
     gboolean use_hsv;
+
+    /* which player will we use */
+    gushort music_player;
+    gchar *music_player_name;
 } GjayPrefs;
 
 
