@@ -1,3 +1,22 @@
+/*
+ * Gjay - Gtk+ DJ music playlist creator
+ * Copyright (C) 2002 Chuck Groom
+ * Copyright (C) 2010-2011 Craig Small 
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2, or (at
+ * your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, see <http://www.gnu.org/licenses/>.
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
@@ -60,7 +79,7 @@ static void     destroy_app           ( void);
 
 void make_app_ui ( void ) {
     GtkWidget * vbox1, * hbox1, * hbox2;
-    GtkWidget * alignment, * menubar, * view;
+    GtkWidget * alignment, * menubar;
     
     /* FIXME
     if (prefs.hide_tips) 
@@ -145,14 +164,7 @@ void make_app_ui ( void ) {
     gtk_notebook_set_page(GTK_NOTEBOOK(gjay->notebook), TAB_EXPLORE);
     
 
-    gjay->prefs_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-    gtk_window_set_title(GTK_WINDOW(gjay->prefs_window), _("GJay Preferences"));
-    gtk_container_set_border_width (GTK_CONTAINER (gjay->prefs_window), 5);
-    view = make_prefs_view();
-    gtk_widget_show_all(view);
-    gtk_signal_connect (GTK_OBJECT (gjay->prefs_window), "delete_event",
-			GTK_SIGNAL_FUNC (gtk_widget_hide), NULL);
-    gtk_container_add (GTK_CONTAINER (gjay->prefs_window), view);
+    gjay->prefs_window = make_prefs_window();
 }
 
 
@@ -547,7 +559,7 @@ void show_about_window( void ) {
   };
   static const gchar copyright[] = \
     "Copyright \xc2\xa9 2004 Chuck Groom\n"
-    "Copyright \xc2\xa9 2010 Craig Small";
+    "Copyright \xc2\xa9 2010-2011 Craig Small";
 
   static const gchar comments[] = \
     "GTK+ playlist generator for a collection of music based upon "
@@ -572,3 +584,15 @@ void show_prefs_window( void ) {
 void hide_prefs_window( void ) {
     gtk_widget_hide(gjay->prefs_window);
 }
+
+void gjay_error_dialog(char *msg) {
+  GtkWidget *dialog;
+
+  dialog = gtk_message_dialog_new(GTK_WINDOW(gjay->main_window),
+      GTK_DIALOG_DESTROY_WITH_PARENT,
+      GTK_MESSAGE_ERROR,
+      GTK_BUTTONS_CLOSE,
+      msg);
+  gtk_dialog_run(GTK_DIALOG(dialog));
+  gtk_widget_destroy(dialog);
+}
