@@ -1,9 +1,11 @@
-/**
- * GJay, copyright (c) 2002-3 Chuck Groom
+/*
+ * Gjay - Gtk+ DJ music playlist creator
+ * Copyright (C) 2002,2003 Chuck Groom
+ * Copyright (C) 2010 Craig Small 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 1, or (at
+ * published by the Free Software Foundation; either version 2, or (at
  * your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
@@ -11,10 +13,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __UI_H__ 
@@ -89,7 +89,7 @@ GtkWidget * make_explore_view ( void );
 GtkWidget * make_playlist_view ( void );
 GtkWidget * make_no_root_view ( void );
 GtkWidget * make_selection_view ( void );
-GtkWidget * make_prefs_view ( void );
+GtkWidget * make_prefs_window ( void );
 GtkWidget * make_about_view ( void );
 GtkWidget * make_message_window( void);
 void        show_about_window ( void );
@@ -105,6 +105,7 @@ void        set_add_files_progress         ( char * str,
 gboolean    quit_app                      ( GtkWidget *widget,
                                             GdkEvent *event,
                                             gpointer user_data );
+void        gjay_error_dialog(char *msg);
 
 /* Explore files pane  */
 void        explore_view_set_root        ( const gchar * root_dir );
