@@ -1,9 +1,11 @@
-/**
- * GJay, copyright (c) 2002-2004 Chuck Groom
+/*
+ * Gjay - Gtk+ DJ music playlist creator
+ * Copyright (C) 2002-2004 Chuck Groom
+ * Copyright (C) 2010 Craig Small 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 1, or (at
+ * published by the Free Software Foundation; either version 2, or (at
  * your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
@@ -11,11 +13,13 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, see <http://www.gnu.org/licenses/>.
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif /* HAVE_CONFIG_H */
+
 #include <sys/types.h>
 #include <dirent.h>
 #include <stdlib.h>
@@ -143,7 +147,7 @@ NULL);
  * Note that root_dir is UTF8 encoded
  */
 void explore_view_set_root (const gchar* root_dir ) {
-    GList * llist;
+    GList * llist=NULL;
     char buffer[BUFFER_SIZE];
 
     if (!root_dir)
@@ -153,7 +157,7 @@ void explore_view_set_root (const gchar* root_dir ) {
     gjay->tree_depth = 0;
     
     /* Unmark current songs */
-    for (llist = g_list_first(gjay->songs); llist; llist = g_list_next(llist)) {
+    for (llist = g_list_first(gjay->songs); llist!=NULL; llist = g_list_next(llist)) {
         SONG(llist)->in_tree = FALSE;
     }
     
