@@ -1,9 +1,11 @@
-/**
- * GJay, copyright (c) 2002-2003 Chuck Groom
+/*
+ * Gjay - Gtk+ DJ music playlist creator
+ * Copyright (C) 2002-2003 Chuck Groom
+ * Copyright (C) 2010 Craig Small 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 1, or (at
+ * published by the Free Software Foundation; either version 2, or (at
  * your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
@@ -11,12 +13,12 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, see <http://www.gnu.org/licenses/>.
  */
-
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif /* HAVE_CONFIG_H */
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -28,6 +30,7 @@
 #include "ipc.h"
 #include "i18n.h"
 
+extern char *music_player_names[];
 
 static char * welcome_str =
   "Welcome to GJay!\n\n" \
@@ -55,18 +58,107 @@ static void click_daemon_radio ( GtkToggleButton *togglebutton,
                                 gpointer user_data );
 static void tooltips_toggled ( GtkToggleButton *togglebutton,
                                gpointer user_data );
+static void player_combo_box_changed(GtkComboBox *combo, gpointer user_data);
 static void useratings_toggled ( GtkToggleButton *togglebutton,
                                  gpointer user_data );
 static void max_working_set_callback (GtkWidget *widget,
                                  gpointer user_data);
 
-GtkWidget * make_prefs_view ( void ) {
-    GtkWidget * vbox1, * vbox2, * alignment, *dir_label, * button, *label;
-    GtkWidget * radio1, * radio2, * radio3;
-    GtkWidget * hseparator, * hbox1, *max_working_set_entry;
-    char buffer[BUFFER_SIZE];
+GtkWidget * make_prefs_window ( void )
+{
+  GtkWidget * window;
+  GtkWidget * vbox1, * vbox2, * alignment, *dir_label, * button, *label;
+  GtkWidget * radio1, * radio2, * radio3;
+  GtkWidget * player_cbox;
+  GtkWidget * hseparator, * hbox1, *max_working_set_entry, *table;
+  char buffer[BUFFER_SIZE];
+  int i;
+
+  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  gtk_window_set_title(GTK_WINDOW(window), _("GJay Preferences"));
+  gtk_container_set_border_width (GTK_CONTAINER (window), 5);
     
     vbox1 = gtk_vbox_new (FALSE, 2);
+    alignment = gtk_alignment_new(0, 0, 0, 0);
+    gtk_box_pack_start(GTK_BOX(vbox1), alignment, TRUE, TRUE, 2);
+    vbox2 = gtk_vbox_new (FALSE, 2);
+    gtk_container_add(GTK_CONTAINER(alignment), vbox2);
+
+    label = gtk_label_new(NULL);
+    gtk_label_set_markup(GTK_LABEL(label),_("<b>General</b>"));
+    gtk_box_pack_start(GTK_BOX(vbox2), label, TRUE, TRUE, 0);
+
+  table = gtk_table_new(3,2,TRUE);
+  gtk_box_pack_start(GTK_BOX(vbox1), table, TRUE, TRUE, 2);
+
+  /* Player selection combo box */
+  label = gtk_label_new(_("Music Player:"));
+
+  player_cbox = gtk_combo_box_new_text();
+  i=0;
+  while (music_player_names[i] != NULL)
+  {
+    gtk_combo_box_append_text(GTK_COMBO_BOX(player_cbox), music_player_names[i]);
+    i++;
+  }
+  gtk_combo_box_set_active(GTK_COMBO_BOX(player_cbox), gjay->prefs->music_player);
+
+  alignment = gtk_alignment_new(0, 0, 0, 0);
+  gtk_container_add(GTK_CONTAINER(alignment), label);
+  gtk_table_attach(GTK_TABLE(table), alignment, 0, 1, 0, 1,
+      (GTK_EXPAND|GTK_FILL),(GTK_EXPAND|GTK_FILL),6,0);
+  alignment = gtk_alignment_new(0, 0, 0, 0);
+  gtk_container_add(GTK_CONTAINER(alignment), player_cbox);
+  gtk_table_attach(GTK_TABLE(table), alignment, 1, 2, 0, 1,
+      (GTK_EXPAND|GTK_FILL),(GTK_EXPAND|GTK_FILL),6,0);
+  g_signal_connect (G_OBJECT (player_cbox), "changed",
+                    G_CALLBACK (player_combo_box_changed), NULL);
+
+    /* Song Ratings checkbox */
+    label = gtk_label_new(_("Use song ratings"));
+
+    button = gtk_check_button_new();
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),
+                                 gjay->prefs->use_ratings);
+    g_signal_connect (G_OBJECT (button), "toggled",
+                      G_CALLBACK (useratings_toggled), NULL);
+
+    alignment = gtk_alignment_new(0, 0, 0, 0);
+    gtk_container_add(GTK_CONTAINER(alignment), label);
+    gtk_table_attach(GTK_TABLE(table), alignment, 0, 1, 1, 2,
+        (GTK_EXPAND|GTK_FILL),(GTK_EXPAND|GTK_FILL),6,0);
+    alignment = gtk_alignment_new(0, 0, 0, 0);
+    gtk_container_add(GTK_CONTAINER(alignment), button);
+    gtk_table_attach(GTK_TABLE(table), alignment, 1, 2, 1, 2,
+        (GTK_EXPAND|GTK_FILL),(GTK_EXPAND|GTK_FILL),6,0);
+
+    /* Maximum working set box */
+    label = gtk_label_new(_("Max working set"));
+
+    max_working_set_entry = gtk_entry_new_with_max_length (6);
+    snprintf(buffer, BUFFER_SIZE, "%d", gjay->prefs->max_working_set);
+    gtk_entry_set_text(GTK_ENTRY(max_working_set_entry), buffer);
+    gtk_widget_set_tooltip_text (max_working_set_entry,
+                          _("On large collections, building playlists can take a long time. So gjay first picks this number of songs randomly, then continues the  selection from that subset. Increase this number if you're willing to tolerate longer waiting times for increased accuracy."));
+
+    gtk_widget_set_size_request(max_working_set_entry, 60, -1);
+    g_signal_connect (G_OBJECT (max_working_set_entry), "changed",
+                      G_CALLBACK (max_working_set_callback), NULL);
+
+    alignment = gtk_alignment_new(0, 0, 0, 0);
+    gtk_container_add(GTK_CONTAINER(alignment), label);
+    gtk_table_attach(GTK_TABLE(table), alignment, 0, 1, 2, 3,
+        (GTK_EXPAND|GTK_FILL),(GTK_EXPAND|GTK_FILL),6,0);
+    alignment = gtk_alignment_new(0, 0, 0, 0);
+    gtk_container_add(GTK_CONTAINER(alignment), max_working_set_entry);
+    gtk_table_attach(GTK_TABLE(table), alignment, 1, 2, 2, 3,
+        (GTK_EXPAND|GTK_FILL),(GTK_EXPAND|GTK_FILL),6,0);
+
+    hseparator = gtk_hseparator_new();
+    gtk_box_pack_start(GTK_BOX(vbox1), hseparator, TRUE, TRUE, 2);
+
+    alignment = gtk_alignment_new(0, 0, 0, 0);
+    gtk_box_pack_start(GTK_BOX(vbox1), alignment, TRUE, TRUE, 0);
 
     alignment = gtk_alignment_new(0, 0, 0, 0);
     gtk_box_pack_start(GTK_BOX(vbox1), alignment, TRUE, TRUE, 2);
@@ -104,15 +196,22 @@ GtkWidget * make_prefs_view ( void ) {
     vbox2 = gtk_vbox_new (FALSE, 2);
     gtk_container_add(GTK_CONTAINER(alignment), vbox2);
 
+    alignment = gtk_alignment_new(0, 0, 0, 0);
+    gtk_box_pack_start(GTK_BOX(vbox1), alignment, TRUE, TRUE, 2);
+    vbox2 = gtk_vbox_new (FALSE, 2);
+    gtk_container_add(GTK_CONTAINER(alignment), vbox2);
+
+    label = gtk_label_new(NULL);
+    gtk_label_set_markup(GTK_LABEL(label),_("<b>Song Analysis Daemon</b>"));
+    gtk_box_pack_start(GTK_BOX(vbox2), label, TRUE, TRUE, 2);
     
-    label = gtk_label_new(_("When you quit, song analysis should..."));
-    radio1 = gtk_radio_button_new_with_label (NULL, _("Stop"));
+    radio1 = gtk_radio_button_new_with_label (NULL, _("Stop daemon when you quit GJay"));
     radio2 = gtk_radio_button_new_with_label_from_widget (
         GTK_RADIO_BUTTON (radio1),
-        _("Continue in background"));
+        _("Continue running daemon when you quit"));
     radio3 = gtk_radio_button_new_with_label_from_widget (
         GTK_RADIO_BUTTON (radio2),
-        _("Ask"));
+        _("Ask each time"));
     if (gjay->prefs->daemon_action == PREF_DAEMON_QUIT) 
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio1), TRUE);
     else if (gjay->prefs->daemon_action == PREF_DAEMON_DETACH) 
@@ -120,7 +219,6 @@ GtkWidget * make_prefs_view ( void ) {
     else
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio3), TRUE);
 
-    gtk_box_pack_start(GTK_BOX(vbox2), label, TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(vbox2), radio1, FALSE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(vbox2), radio2, FALSE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(vbox2), radio3, FALSE, TRUE, 0);
@@ -137,53 +235,7 @@ GtkWidget * make_prefs_view ( void ) {
     hseparator = gtk_hseparator_new();
     gtk_box_pack_start(GTK_BOX(vbox1), hseparator, TRUE, TRUE, 2);
 
-    alignment = gtk_alignment_new(0, 0, 0, 0);
-    gtk_box_pack_start(GTK_BOX(vbox1), alignment, TRUE, TRUE, 0);
-
-    /*button = gtk_check_button_new_with_label("Show popup tips");
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),
-                                 !(gjay->prefs->hide_tips));
-    g_signal_connect (G_OBJECT (button), "toggled",
-                      G_CALLBACK (tooltips_toggled), NULL);
-    gtk_container_add(GTK_CONTAINER(alignment), button);
-*/
-
-    hseparator = gtk_hseparator_new();
-    gtk_box_pack_start(GTK_BOX(vbox1), hseparator, TRUE, TRUE, 2);
-
-    alignment = gtk_alignment_new(0, 0, 0, 0);
-    gtk_box_pack_start(GTK_BOX(vbox1), alignment, TRUE, TRUE, 0);
-
-    button = gtk_check_button_new_with_label(_("Use song ratings"));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),
-                                 gjay->prefs->use_ratings);
-    g_signal_connect (G_OBJECT (button), "toggled",
-                      G_CALLBACK (useratings_toggled), NULL);
-    gtk_container_add(GTK_CONTAINER(alignment), button);
-
-
-    hseparator = gtk_hseparator_new();
-    gtk_box_pack_start(GTK_BOX(vbox1), hseparator, TRUE, TRUE, 2);
-
-    label = gtk_label_new(_("Max working set"));
-    max_working_set_entry = gtk_entry_new_with_max_length (6);
-    snprintf(buffer, BUFFER_SIZE, "%d", gjay->prefs->max_working_set);
-    gtk_entry_set_text(GTK_ENTRY(max_working_set_entry), buffer);
-    gtk_widget_set_tooltip_text (max_working_set_entry,
-                          _("On large collections, building playlists can take a long time. So gjay first picks this number of songs randomly, then continues the  selection from that subset. Increase this number if you're willing to tolerate longer waiting times for increased accuracy."));
-
-    gtk_widget_set_size_request(max_working_set_entry, 60, -1);
-    g_signal_connect (G_OBJECT (max_working_set_entry), "changed",
-                      G_CALLBACK (max_working_set_callback), NULL);
-    hbox1 = gtk_hbox_new(FALSE, 2);
-    gtk_box_pack_start(GTK_BOX(hbox1), label, FALSE, FALSE, 2);
-    gtk_box_pack_start(GTK_BOX(hbox1), max_working_set_entry, FALSE, FALSE, 2);
-    gtk_box_pack_start(GTK_BOX(vbox1), hbox1, TRUE, TRUE, 0);
-
-    hseparator = gtk_hseparator_new();
-    gtk_box_pack_start(GTK_BOX(vbox1), hseparator, TRUE, TRUE, 2);
-
-    alignment = gtk_alignment_new(1, 0, 0.3, 0);
+    alignment = gtk_alignment_new(0, 0, 0.3, 0);
     gtk_box_pack_start(GTK_BOX(vbox1), alignment, TRUE, TRUE, 0);
 
     button = gtk_button_new_from_stock(GTK_STOCK_OK);
@@ -192,7 +244,12 @@ GtkWidget * make_prefs_view ( void ) {
                       "clicked",
                       G_CALLBACK (hide_prefs_window),
                       NULL);
-    return vbox1;
+  gtk_widget_show_all(vbox1);
+
+  gtk_signal_connect (GTK_OBJECT (window), "delete_event",
+    GTK_SIGNAL_FUNC (gtk_widget_hide), NULL);
+  gtk_container_add (GTK_CONTAINER (window), vbox1);
+  return window;
 }
 
 
@@ -332,6 +389,20 @@ click_daemon_radio ( GtkToggleButton *togglebutton, gpointer user_data )
     }
 }
 
+static void player_combo_box_changed(GtkComboBox *combo, gpointer user_data)
+{
+  gint new_player;
+
+  new_player = gtk_combo_box_get_active(combo);
+  if (new_player >= 0)
+  {
+    g_free(gjay->prefs->music_player_name);
+    gjay->prefs->music_player_name = gtk_combo_box_get_active_text(combo);
+    gjay->prefs->music_player = new_player;
+    save_prefs();
+  }
+}
+
 static void tooltips_toggled ( GtkToggleButton *togglebutton,
                                gpointer user_data ) {
     /* FIXME
