@@ -1,9 +1,11 @@
-/**
- * GJay, copyright (c) 2002, 2003 Chuck Groom
+/*
+ * Gjay - Gtk+ DJ music playlist creator
+ * Copyright (C) 2002,2003 Chuck Groom
+ * Copyright (C) 2010 Craig Small 
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 1, or (at
+ * published by the Free Software Foundation; either version 2, or (at
  * your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
@@ -11,11 +13,12 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, see <http://www.gnu.org/licenses/>.
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif /* HAVE_CONFIG_H */
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -23,7 +26,6 @@
 #include <math.h>
 #include <string.h>
 #include "gjay.h"
-#include "gjay_audacious.h"
 #include "ui.h"
 #include "rgbhsv.h"
 
